#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
# Copyright (C) 2010  Rafal Wojtczuk  <rafal@invisiblethingslab.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <https://www.gnu.org/licenses/>.
#
#

%define _dracutmoddir	/usr/lib/dracut/modules.d
%define backend_vmm xen

Name:		qubes-core-dom0
Version:	4.0.59
Release:	1%{dist}
Summary:	The Qubes core files (Dom0-side)

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

# because we have "#!/usr/bin/env python" shebangs, RPM puts
# "Requires: $(which # python)" dependency, which, depending on $PATH order,
# may point to /usr/bin/python or /bin/python (because Fedora has this stupid
# /bin -> usr/bin symlink). python*.rpm provides only /usr/bin/python.
AutoReq:	no

# FIXME: Enable this and disable debug_package
#BuildArch: noarch

BuildRequires:  ImageMagick
BuildRequires:	systemd-units
BuildRequires:  systemd
BuildRequires:  gcc

BuildRequires:  python3-devel

# for building documentation
BuildRequires:	python3-sphinx
BuildRequires:	python3-lxml
BuildRequires:	libvirt-python3
BuildRequires:	python3-dbus
BuildRequires:	python3-PyYAML
BuildRequires:  python3-xen

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

Requires:       python3
#Requires:       python3-aiofiles
Requires:       python3-docutils
Requires:       python3-jinja2
Requires:       python3-lxml
Requires:       python3-pydbus
Requires:       python3-qubesdb
Requires:       python3-setuptools
Requires:       python3-PyYAML
Requires:       python3-xen
Requires:       libvirt-python3

Requires:       pciutils
Requires:       qubes-core-dom0-linux >= 4.0.11
Requires:       qubes-db-dom0
# TODO: R: qubes-gui-dom0 >= 2.1.11
Conflicts:      qubes-gui-dom0 < 1.1.13
%if "x%{?backend_vmm}" == "xxen"
Requires:       xen-runtime
Requires:       xen-hvm
Requires:       xen-hvm-stubdom-linux
Requires:       libvirt-daemon-xen >= 3.3.0-10
%endif
Requires:       createrepo
Requires:       cronie
Requires:       scrypt
# for qubes-hcl-report
Requires:       dmidecode

# Required for qvm-console* tools
Requires:       socat

%{?systemd_requires}

Obsoletes:	qubes-core-dom0-doc <= 4.0
Provides:	qubes-core-dom0-doc

# Prevent preupgrade from installation (it pretend to provide distribution upgrade)
Obsoletes:	preupgrade < 2.0
Provides:	preupgrade = 2.0

Source0: %{name}-%{version}.tar.gz

%description
The Qubes core files for installation on Dom0.

%prep
%setup -q

%build

make all
make -C doc PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} man

%install

make install \
    DESTDIR=$RPM_BUILD_ROOT \
    BACKEND_VMM=%{backend_vmm} \
    UNITDIR=%{_unitdir} \
    PYTHON_SITEPATH=%{python3_sitelib} \
    SYSCONFDIR=%{_sysconfdir}

make -C doc DESTDIR=$RPM_BUILD_ROOT \
    PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} \
    install

mkdir -p $RPM_BUILD_ROOT/etc/qubes/backup


%post
%systemd_post qubes-core.service
%systemd_post qubes-qmemman.service
%systemd_post qubesd.service

sed '/^autoballoon=/d;/^lockfile=/d' -i /etc/xen/xl.conf
echo 'autoballoon=0' >> /etc/xen/xl.conf
echo 'lockfile="/var/run/qubes/xl-lock"' >> /etc/xen/xl.conf

if [ -e /etc/sysconfig/prelink ]; then
sed 's/^PRELINKING\s*=.*/PRELINKING=no/' -i /etc/sysconfig/prelink
fi

# Conflicts with libxl stack, so disable it
systemctl --no-reload disable xend.service >/dev/null 2>&1
systemctl --no-reload disable xendomains.service >/dev/null 2>&1
systemctl daemon-reload >/dev/null 2>&1 || :

if ! [ -e /var/lib/qubes/qubes.xml ]; then
#    echo "Initializing Qubes DB..."
    umask 007; sg qubes -c 'qubes-create --offline-mode'
fi

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%pre
if ! grep -q ^qubes: /etc/group ; then
		groupadd qubes
fi

%triggerin -- xen-runtime
/usr/lib/qubes/fix-dir-perms.sh

%preun
%systemd_preun qubes-core.service
%systemd_preun qubes-qmemman.service
%systemd_preun qubesd.service

if [ "$1" = 0 ] ; then
	# no more packages left
    service qubes_netvm stop
    service qubes_core stop
fi

%postun
%systemd_postun qubes-core.service
%systemd_postun_with_restart qubes-qmemman.service
%systemd_postun_with_restart qubesd.service

if [ "$1" = 0 ] ; then
	# no more packages left
    chgrp root /etc/xen
    chmod 700 /etc/xen
    groupdel qubes
fi

%files
%defattr(-,root,root,-)
%config(noreplace) %attr(0664,root,qubes) %{_sysconfdir}/qubes/qmemman.conf
%config(noreplace) /etc/dbus-1/system.d/org.qubesos.PolicyAgent.conf
%config(noreplace) /etc/logrotate.d/qubes
%attr(770,root,qubes) %dir /etc/qubes/backup
/usr/bin/qvm-*
/usr/bin/qubes-*
/usr/bin/qmemmand
/usr/bin/qubesd*
/usr/bin/qrexec-policy
/usr/bin/qrexec-policy-agent
/usr/bin/qrexec-policy-graph

%{_mandir}/man1/qrexec-policy-graph.1*
%{_mandir}/man1/qubes*.1*
%{_mandir}/man1/qvm-*.1*

%dir %{python3_sitelib}/qubes-*.egg-info
%{python3_sitelib}/qubes-*.egg-info/*

%dir %{python3_sitelib}/qubes
%dir %{python3_sitelib}/qubes/__pycache__
%{python3_sitelib}/qubes/__pycache__/*
%{python3_sitelib}/qubes/__init__.py
%{python3_sitelib}/qubes/app.py
%{python3_sitelib}/qubes/backup.py
%{python3_sitelib}/qubes/config.py
%{python3_sitelib}/qubes/devices.py
%{python3_sitelib}/qubes/dochelpers.py
%{python3_sitelib}/qubes/events.py
%{python3_sitelib}/qubes/exc.py
%{python3_sitelib}/qubes/features.py
%{python3_sitelib}/qubes/firewall.py
%{python3_sitelib}/qubes/log.py
%{python3_sitelib}/qubes/rngdoc.py
%{python3_sitelib}/qubes/tarwriter.py
%{python3_sitelib}/qubes/utils.py

%dir %{python3_sitelib}/qubes/api
%dir %{python3_sitelib}/qubes/api/__pycache__
%{python3_sitelib}/qubes/api/__pycache__/*
%{python3_sitelib}/qubes/api/__init__.py
%{python3_sitelib}/qubes/api/admin.py
%{python3_sitelib}/qubes/api/internal.py
%{python3_sitelib}/qubes/api/misc.py

%dir %{python3_sitelib}/qubes/vm
%dir %{python3_sitelib}/qubes/vm/__pycache__
%{python3_sitelib}/qubes/vm/__pycache__/*
%{python3_sitelib}/qubes/vm/__init__.py
%{python3_sitelib}/qubes/vm/adminvm.py
%{python3_sitelib}/qubes/vm/appvm.py
%{python3_sitelib}/qubes/vm/dispvm.py
%{python3_sitelib}/qubes/vm/qubesvm.py
%{python3_sitelib}/qubes/vm/standalonevm.py
%{python3_sitelib}/qubes/vm/templatevm.py

%dir %{python3_sitelib}/qubes/vm/mix
%dir %{python3_sitelib}/qubes/vm/mix/__pycache__
%{python3_sitelib}/qubes/vm/mix/__pycache__/*
%{python3_sitelib}/qubes/vm/mix/__init__.py
%{python3_sitelib}/qubes/vm/mix/net.py

%dir %{python3_sitelib}/qubes/storage
%dir %{python3_sitelib}/qubes/storage/__pycache__
%{python3_sitelib}/qubes/storage/__pycache__/*
%{python3_sitelib}/qubes/storage/__init__.py
%{python3_sitelib}/qubes/storage/file.py
%{python3_sitelib}/qubes/storage/reflink.py
%{python3_sitelib}/qubes/storage/kernels.py
%{python3_sitelib}/qubes/storage/lvm.py

%dir %{python3_sitelib}/qubes/tools
%dir %{python3_sitelib}/qubes/tools/__pycache__
%{python3_sitelib}/qubes/tools/__pycache__/*
%{python3_sitelib}/qubes/tools/__init__.py
%{python3_sitelib}/qubes/tools/qmemmand.py
%{python3_sitelib}/qubes/tools/qubes_create.py
%{python3_sitelib}/qubes/tools/qubesd.py
%{python3_sitelib}/qubes/tools/qubesd_query.py

%dir %{python3_sitelib}/qubes/ext
%dir %{python3_sitelib}/qubes/ext/__pycache__
%{python3_sitelib}/qubes/ext/__pycache__/*
%{python3_sitelib}/qubes/ext/__init__.py
%{python3_sitelib}/qubes/ext/admin.py
%{python3_sitelib}/qubes/ext/block.py
%{python3_sitelib}/qubes/ext/core_features.py
%{python3_sitelib}/qubes/ext/gui.py
%{python3_sitelib}/qubes/ext/pci.py
%{python3_sitelib}/qubes/ext/qubesmanager.py
%{python3_sitelib}/qubes/ext/r3compatibility.py
%{python3_sitelib}/qubes/ext/services.py
%{python3_sitelib}/qubes/ext/windows.py

%dir %{python3_sitelib}/qubes/tests
%dir %{python3_sitelib}/qubes/tests/__pycache__
%{python3_sitelib}/qubes/tests/__pycache__/*
%{python3_sitelib}/qubes/tests/__init__.py
%{python3_sitelib}/qubes/tests/run.py
%{python3_sitelib}/qubes/tests/extra.py

%{python3_sitelib}/qubes/tests/api.py
%{python3_sitelib}/qubes/tests/api_admin.py
%{python3_sitelib}/qubes/tests/api_internal.py
%{python3_sitelib}/qubes/tests/api_misc.py
%{python3_sitelib}/qubes/tests/app.py
%{python3_sitelib}/qubes/tests/devices.py
%{python3_sitelib}/qubes/tests/devices_block.py
%{python3_sitelib}/qubes/tests/events.py
%{python3_sitelib}/qubes/tests/ext.py
%{python3_sitelib}/qubes/tests/firewall.py
%{python3_sitelib}/qubes/tests/init.py
%{python3_sitelib}/qubes/tests/storage.py
%{python3_sitelib}/qubes/tests/storage_file.py
%{python3_sitelib}/qubes/tests/storage_reflink.py
%{python3_sitelib}/qubes/tests/storage_kernels.py
%{python3_sitelib}/qubes/tests/storage_lvm.py
%{python3_sitelib}/qubes/tests/tarwriter.py

%dir %{python3_sitelib}/qubes/tests/vm
%dir %{python3_sitelib}/qubes/tests/vm/__pycache__
%{python3_sitelib}/qubes/tests/vm/__pycache__/*
%{python3_sitelib}/qubes/tests/vm/__init__.py
%{python3_sitelib}/qubes/tests/vm/init.py
%{python3_sitelib}/qubes/tests/vm/adminvm.py
%{python3_sitelib}/qubes/tests/vm/appvm.py
%{python3_sitelib}/qubes/tests/vm/dispvm.py
%{python3_sitelib}/qubes/tests/vm/qubesvm.py

%dir %{python3_sitelib}/qubes/tests/vm/mix
%dir %{python3_sitelib}/qubes/tests/vm/mix/__pycache__
%{python3_sitelib}/qubes/tests/vm/mix/__pycache__/*
%{python3_sitelib}/qubes/tests/vm/mix/__init__.py
%{python3_sitelib}/qubes/tests/vm/mix/net.py

%dir %{python3_sitelib}/qubes/tests/tools
%dir %{python3_sitelib}/qubes/tests/tools/__pycache__
%{python3_sitelib}/qubes/tests/tools/__pycache__/*
%{python3_sitelib}/qubes/tests/tools/__init__.py

%dir %{python3_sitelib}/qubes/tests/integ
%dir %{python3_sitelib}/qubes/tests/integ/__pycache__
%{python3_sitelib}/qubes/tests/integ/__pycache__/*
%{python3_sitelib}/qubes/tests/integ/__init__.py
%{python3_sitelib}/qubes/tests/integ/backup.py
%{python3_sitelib}/qubes/tests/integ/backupcompatibility.py
%{python3_sitelib}/qubes/tests/integ/basic.py
%{python3_sitelib}/qubes/tests/integ/devices_block.py
%{python3_sitelib}/qubes/tests/integ/devices_pci.py
%{python3_sitelib}/qubes/tests/integ/dispvm.py
%{python3_sitelib}/qubes/tests/integ/dom0_update.py
%{python3_sitelib}/qubes/tests/integ/vm_update.py
%{python3_sitelib}/qubes/tests/integ/mime.py
%{python3_sitelib}/qubes/tests/integ/network.py
%{python3_sitelib}/qubes/tests/integ/network_ipv6.py
%{python3_sitelib}/qubes/tests/integ/grub.py
%{python3_sitelib}/qubes/tests/integ/salt.py
%{python3_sitelib}/qubes/tests/integ/qrexec.py
%{python3_sitelib}/qubes/tests/integ/storage.py
%{python3_sitelib}/qubes/tests/integ/vm_qrexec_gui.py

%dir %{python3_sitelib}/qubes/tests/integ/tools
%dir %{python3_sitelib}/qubes/tests/integ/tools/__pycache__
%{python3_sitelib}/qubes/tests/integ/tools/__pycache__/*
%{python3_sitelib}/qubes/tests/integ/tools/__init__.py
%{python3_sitelib}/qubes/tests/integ/tools/qubes_create.py

%dir %{python3_sitelib}/qubes/qmemman
%dir %{python3_sitelib}/qubes/qmemman/__pycache__
%{python3_sitelib}/qubes/qmemman/__pycache__/*
%{python3_sitelib}/qubes/qmemman/__init__.py
%{python3_sitelib}/qubes/qmemman/algo.py
%{python3_sitelib}/qubes/qmemman/client.py

%dir %{python3_sitelib}/qubespolicy
%dir %{python3_sitelib}/qubespolicy/__pycache__
%{python3_sitelib}/qubespolicy/__pycache__/*
%{python3_sitelib}/qubespolicy/__init__.py
%{python3_sitelib}/qubespolicy/cli.py
%{python3_sitelib}/qubespolicy/agent.py
%{python3_sitelib}/qubespolicy/gtkhelpers.py
%{python3_sitelib}/qubespolicy/policycreateconfirmation.py
%{python3_sitelib}/qubespolicy/rpcconfirmation.py
%{python3_sitelib}/qubespolicy/utils.py
%{python3_sitelib}/qubespolicy/graph.py

%dir %{python3_sitelib}/qubespolicy/tests
%dir %{python3_sitelib}/qubespolicy/tests/__pycache__
%{python3_sitelib}/qubespolicy/tests/__pycache__/*
%{python3_sitelib}/qubespolicy/tests/__init__.py
%{python3_sitelib}/qubespolicy/tests/cli.py
%{python3_sitelib}/qubespolicy/tests/gtkhelpers.py
%{python3_sitelib}/qubespolicy/tests/rpcconfirmation.py

%dir %{python3_sitelib}/qubespolicy/glade
%{python3_sitelib}/qubespolicy/glade/PolicyCreateConfirmationWindow.glade
%{python3_sitelib}/qubespolicy/glade/RPCConfirmationWindow.glade

/usr/lib/qubes/cleanup-dispvms
/usr/lib/qubes/fix-dir-perms.sh
/usr/lib/qubes/startup-misc.sh
/usr/libexec/qubes/qubesd-query-fast
%{_unitdir}/lvm2-pvscan@.service.d/30_qubes.conf
%{_unitdir}/qubes-core.service
%{_unitdir}/qubes-qmemman.service
%{_unitdir}/qubes-vm@.service
%{_unitdir}/qubesd.service
%attr(2770,root,qubes) %dir /var/lib/qubes
%attr(2770,root,qubes) %dir /var/lib/qubes/vm-templates
%attr(2770,root,qubes) %dir /var/lib/qubes/appvms
%attr(2770,root,qubes) %dir /var/lib/qubes/backup
%attr(2770,root,qubes) %dir /var/lib/qubes/vm-kernels
/usr/share/qubes/templates/libvirt/xen.xml
/usr/share/qubes/templates/libvirt/devices/block.xml
/usr/share/qubes/templates/libvirt/devices/pci.xml
/usr/share/qubes/templates/libvirt/devices/net.xml
/usr/lib/tmpfiles.d/qubes.conf
/etc/xen/scripts/block-snapshot
/etc/xen/scripts/block-origin
/etc/xen/scripts/vif-route-qubes
%attr(2775,root,qubes) %dir /etc/qubes-rpc/policy
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/admin.*
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/include/admin-local-ro
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/include/admin-local-rwx
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/include/admin-global-ro
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/include/admin-global-rwx
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.ConnectTCP
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.FeaturesRequest
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.Filecopy
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.GetImageRGBA
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.GetRandomizedTime
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.NotifyTools
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.NotifyUpdates
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.OpenInVM
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.OpenURL
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.StartApp
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.VMShell
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.VMRootShell
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.UpdatesProxy
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/qubes.GetDate
%attr(0664,root,qubes) %config(noreplace) /etc/qubes-rpc/policy/policy.RegisterArgument
/etc/qubes-rpc/admin.*
/etc/qubes-rpc/qubes.FeaturesRequest
/etc/qubes-rpc/qubes.GetDate
/etc/qubes-rpc/qubes.GetRandomizedTime
/etc/qubes-rpc/qubes.NotifyTools
/etc/qubes-rpc/qubes.NotifyUpdates
/etc/qubes-rpc/qubes.ConnectTCP
/etc/qubes-rpc/policy.RegisterArgument
%attr(2770,root,qubes) %dir /var/log/qubes
%attr(0770,root,qubes) %dir /var/run/qubes
/etc/xdg/autostart/qrexec-policy-agent.desktop

/usr/share/doc/qubes/relaxng/*.rng

%changelog
* Tue Dec 07 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-admin.git

* Tue Dec 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8d547d5e
- version 4.0.59

* Tue Dec 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a159bb7a
- ci: Use docker f32 image for unit tests

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 281e4a8a
- app: use suppress() in simple cases

* Fri Dec 03 2021 deeplow <47065258+deeplow@users.noreply.github.com> - e7da5c07
- add "events_enabled" to all other examples

* Fri Dec 03 2021 deeplow <47065258+deeplow@users.noreply.github.com> - 872c7d4f
- add missing "events_enabled = True"

* Fri Dec 03 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 66f29019
- Forbid VM name ending with -dm

* Fri Dec 03 2021 Brendan Hoar <brendan.hoar@gmail.com> - 5f7f7fdf
- Update lvm.py

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 9038a63f
- storage: avoid concurrent umask()

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 35842de0
- storage/file: delete -cow.img.old on volume remove()

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 7176b034
- storage/file: add is_outdated() that always returns False

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - f5847dae
- vm/qubesvm: omit stray 'import qubes.storage.file'

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 0414f038
- utils: "parallel" -> "concurrent"

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - e73262f1
- Drop obsolete core2 dvmdata/ and servicevms/ directories

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 01de9da3
- storage/file: fix is_dirty() false positive

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - c1f6a2c9
- app: save qubes.xml with utils.replace_file()

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 7c2e3fcc
- firewall: save firewall.xml with utils.replace_file()

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - d9785556
- utils: take tweaked helper functions from storage/reflink

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 33bebb88
- storage/reflink: quote logged filenames

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 5326fc6f
- log: don't write to qubes.log or vm-*.log, only stderr

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 575b9f79
- log: remove unused DBusHandler

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 080acd05
- log: avoid qubesd restart on logrotate

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - ca467f5c
- log: remove orphaned LOGFILE variable

* Fri Dec 03 2021 Rusty Bird <rustybird@net-c.com> - 32bb67eb
- storage/file: refactor is_dirty()

* Wed Mar 03 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ee34eb2a
- version 4.0.58

* Wed Mar 03 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 18072635
- tools/qubesd-query: limit maximum payload size

* Wed Mar 03 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 94b30b37
- Limit maximum length of kernelopts property

* Wed Mar 03 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f354d46e
- Validate network related features values

* Wed Mar 03 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4bbfbca6
- Enable autoescape in libvirt xml template

* Wed Feb 10 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 099546d4
- version 4.0.57

* Fri Jan 29 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fe66e3db
- storage/file: drop part of export lock

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 37a07959
- version 4.0.56

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d339a69b
- gitlab-ci: install dependencies via dnf

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a905d21b
- tests: skip pvgrub tests on Fedora

* Thu Jan 07 2021 Matt McCutchen <matt@mattmccutchen.net> - 589f64c4
- qubes-hcl-report: run lspci as root

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - e976fd71
- make pylint happy

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 7d50c517
- Avoid permission problems

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 343725ad
- Fix tests for DispVMs

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - ab454341
- Try to get the tests to work

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 582f1db6
- Fix test suite

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 822cf9aa
- Test that a DispVM’s template can be changed

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - c5f019a0
- DispVM has no “default_volume_config” property

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - d680afc3
- Changing AppVM template breaks running DispVMs

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 7c3f7562
- Implement changing the template of a DispVM

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8712d52a
- tests: fix duplicated entries in TestVMsCollection

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6b41d04c
- vm: do not allow setting template_for_dispvms=False if there are any DispVMs

* Thu Jan 07 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - ec2c74d4
- Enhance qvm-console-dispvm and admin.vm.Console

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0eb95044
- Refuse to export a file volume of a running VM

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a61d35fd
- tests: fix test_550_ipv6_spoof_ip

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5d9ab2cd
- tests: wait for full VM startup before testing network and few other

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c20fd70a
- rpm: fix %if syntax

